@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use base 'Perl::Tidy::Sweetened';
 
-our $VERSION = '1.12';
+our $VERSION = '1.14';
 
 1;
 
@@ -20,7 +20,7 @@ Perl::Tidy::Sweet - Tweaks to Perl::Tidy to support some syntactic sugar
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 STATUS
 
@@ -56,6 +56,12 @@ following modules, but most of the new syntax styles should work:
 
 =item * MooseX::Declare
 
+=item * Moops
+
+=item * perl 5.20 signatures
+
+=item * Kavorka
+
 =back
 
 =head1 SEE ALSO
@@ -86,6 +92,10 @@ Curtis Brandt (@aggrolite)
 
 @pblaberge
 
+=item *
+
+Peter Roberts (@pwr22)
+
 =back
 
 =head1 SOURCE
@@ -102,7 +112,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2018 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
